<br />

<div align="center">
<h1>Wattpad</h1>
<p><h3 align="center">Fully-typed Wattpad API Wrapper</h3></p>
    <div align="center">

<a href="https://www.gnu.org/licenses/gpl-3.0">
    <img src="https://img.shields.io/badge/License-GPLv3-blue.svg?style=for-the-badge" alt="GPLv3">
</a>
<a href="https://pypi.org/projects/wattpad">
    <img src="https://img.shields.io/pypi/dm/wattpad?style=for-the-badge&logo=python&logoColor=white&link=https%3A%2F%2Fpypi.org%2Fproject%2Fwattpad" alt="PyPI Downloads">
</a>
<a href="https://pypi.org/projects/wattpad">
    <img src="https://img.shields.io/pypi/v/wattpad?style=for-the-badge" alt="PyPI Version">
</a>
<a href="#">
    <img src="https://img.shields.io/badge/Green%20Code-gray?style=for-the-badge&logo=gumtree&logoColor=white&labelColor=green" alt="Green Code">
</a>
<img src="https://img.shields.io/pypi/pyversions/wattpad?style=for-the-badge" alt="Supported python versions">
    </div>
</div>

<hr>

## What is `wattpad`?
The `wattpad` package is an asynchronous wrapper around the Wattpad User API.

```sh
pip install -U wattpad
```
[Read the Docs](https://wattpad.rambhat.la).

---


<!-- ![GIF showcasing Wattpad Python usage](showcase.gif)

> _Note that the only language server that is known to support this form of autocompletion is Pylance / Pyright._ -->

## Why should you use `wattpad`?

Unlike other API Wrappers (which don't exist, or don't work), `wattpad` is **fully typed** and offers native support for **asynchronous usage**.

`wattpad` is also memory and resource efficient, to the extent of meriting the `Green Code` badge.

The most compelling of all, is the **autocompletion support**. (For autocomplete like the GIF above, press `ctrl + .`.)

### Core features:

- [Memory Efficiency & Caching](https://wattpad.rambhat.la/memory-efficiency)
- [Asynchronous Usage](https://wattpad.rambhat.la/sync-and-async)
- [Autocompletion Support and Fully Typed Codebase](https://wattpad.rambhat.la/types-and-autocompletion)

### Using `wattpad`
Check out the [quickstart notebook](https://wattpad.rambhat.la/quickstart)!

For a more thorough introduction, visit the [documentation](https:/wattpad.rambhat.la).


## Support

Have any questions or need help using `wattpad`? Join the [community discord](https://discord.gg/edyB4k3hwU)!

You can also create a new [discussion on GitHub](https://github.com/TheOnlyWayUp/wattpad/discussions/new).



## Affiliation

The `wattpad` package is _not_ an official Wattpad product.


### Supported platforms

Windows, MacOS and Linux are all officially supported.


## Contributing

We use [conventional commits](https://www.conventionalcommits.org) (also known as semantic commits) to ensure consistent and descriptive commit messages.

## Attributions

This README is heavily inspired by the README in the [RobertCraigie/prisma-client-py](https://github.com/RobertCraigie/prisma-client-py) repository.
